import { defineThemeConfig } from "vuepress-theme-hope";
import * as navbar from "./navbar";
import * as sidebar from "./sidebar";

export default defineThemeConfig({
  hostname: "https://xjtu.sfa.ac.cn",

  author: {
    name: "XJTU-SFA",
    url: "https://xjtu.sfa.ac.cn",
  },

  iconPrefix: "iconfont icon-",

  logo: "/logo.svg",

  repo: "https://git.xjtustei.nteren.net/XJTU-SFA/sfa-blog",

  docsDir: "/",

  contributors: true,

  editLink: true,

  editLinkPattern: ":repo/_edit/:branch/:path",

  docsBranch: "master",

  blog: {
    medias: {
      // Baidu: "https://example.com",
      // Bitbucket: "https://example.com",
      // Dingding: "https://example.com",
      // Discord: "https://example.com",
      // Dribbble: "https://example.com",
      Email: "xjtu@sfa.ac.cn",
      // Evernote: "https://example.com",
      // Facebook: "https://example.com",
      // Flipboard: "https://example.com",
      // Gitee: "https://gitee.com/18842378119",
      // GitHub: "https://example.com",
      // Gitlab: "https://example.com",
      // Gmail: "https://example.com",
      // Instagram: "https://example.com",
      // Lines: "https://example.com",
      // Linkedin: "https://example.com",
      // Pinterest: "https://example.com",
      // Pocket: "https://example.com",
      QQ: "https://jq.qq.com/?_wv=1027&k=T1eDkjvk",
      // Qzone: "https://example.com",
      // Reddit: "https://example.com",
      // Rss: "https://example.com",
      // Steam: "https://example.com",
      // Twitter: "https://example.com",
      // Wechat: "西交幻协",
      // Weibo: "https://example.com",
      // Whatsapp: "https://example.com",
      // Youtube: "https://example.com",
      // Zhihu: "https://example.com",
    },
  },

  locales: {
    // "/": {
    //   // navbar
    //   navbar: navbar.en,

    //   // sidebar
    //   sidebar: sidebar.en,

    //   footer: "Default footer",

    //   displayFooter: true,

    //   blog: {
    //     description: "A FrontEnd programmer",
    //     intro: "/intro.html",
    //   },

    //   metaLocales: {
    //     editLink: "Edit this page on GitHub",
    //   },
    // },

    /**
     * Chinese locale config
     */
    "/": {
      // navbar
      navbar: navbar.zh,

      // sidebar
      sidebar: sidebar.zh,

      headingDepth: 2,

      footer: "Powered by VuePress, Served by Nginx",

      displayFooter: true,

      blog: {
        description: "XJTU-SFA",
        intro: "/intro.html",
      },

      // page meta
      metaLocales: {
        editLink: "在 Gitea 上编辑此页",
      },
    },
  },

  encrypt: {
    config: {
    },
  },

  plugins: {
    blog: {
      autoExcerpt: true,
    },

    // comment: {
    //   type: "waline",
    //   serverURL: "https://vuepress-theme-hope-comment.vercel.app",
    // },

    mdEnhance: {
      enableAll: true,
      presentation: {
        plugins: ["highlight", "math", "search", "notes", "zoom"],
      },
    },
    
    search: {
      locales: {
        '/': {
          placeholder: '搜索',
        },
      },
      hotKeys: ['s', '/'],
      maxSuggestions: 5,
      isSearchable: (page) => page.path !== '/',
      getExtraFields: (page) => [],
    },
    


    pwa: {
      favicon: "/favicon.ico",
      cachePic: true,
      apple: {
        icon: "/assets/icon/apple-icon-152.png",
        statusBarColor: "black",
      },
      msTile: {
        image: "/assets/icon/ms-icon-144.png",
        color: "#ffffff",
      },
      manifest: {
        icons: [
          {
            src: "/assets/icon/chrome-mask-512.png",
            sizes: "512x512",
            purpose: "maskable",
            type: "image/png",
          },
          {
            src: "/assets/icon/chrome-mask-192.png",
            sizes: "192x192",
            purpose: "maskable",
            type: "image/png",
          },
          {
            src: "/assets/icon/chrome-512.png",
            sizes: "512x512",
            type: "image/png",
          },
          {
            src: "/assets/icon/chrome-192.png",
            sizes: "192x192",
            type: "image/png",
          },
        ],
        shortcuts: [
          // {
          //   name: "Guide",
          //   short_name: "Guide",
          //   url: "/guide/",
          //   icons: [
          //     {
          //       src: "/assets/icon/guide-maskable.png",
          //       sizes: "192x192",
          //       purpose: "maskable",
          //       type: "image/png",
          //     },
          //     {
          //       src: "/assets/icon/guide-monochrome.png",
          //       sizes: "192x192",
          //       purpose: "monochrome",
          //       type: "image/png",
          //     },
          //   ],
          // },
        ],
      },
    },
  },
});
